<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>DatabaseSelectorWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.cpp" line="209"/>
        <source>Reset actual prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.cpp" line="210"/>
        <source>You have selected a different drugs database than the currently-opened one. Your actual prescription will be resetted. Do you want to continue ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.cpp" line="212"/>
        <source>Drugs database selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DosageCreatorDialog</name>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="173"/>
        <source>Dosage is not valid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="175"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="197"/>
        <source>Drug Dosage Creator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="191"/>
        <source>Dosage correctly saved to base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="193"/>
        <source>SQL Error : Dosage can not be added to database : %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::DrugsCentralWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugscentralwidget.cpp" line="174"/>
        <source>Can not add this drug to your prescription.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugscentralwidget.cpp" line="175"/>
        <source>Prescription can not contains twice the sample pharmaceutical drug.
Drug %1 is already in your prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugscentralwidget.cpp" line="178"/>
        <source>If you want to change the dosage of this drug please double-click on it in the prescription box.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::DynamicAlert</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dynamicalert.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dynamicalert.cpp" line="81"/>
        <source>Drug interaction alert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dynamicalert.cpp" line="143"/>
        <source>Accept alert and cancel last action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dynamicalert.cpp" line="150"/>
        <source>Override alert and go on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dynamicalert.cpp" line="157"/>
        <source>Show full interactions information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::InteractionSynthesisDialog</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="71"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="116"/>
        <source>Risk and management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="122"/>
        <source>Risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="129"/>
        <source>Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="159"/>
        <source>Drug-drug interaction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="208"/>
        <source>Tree classification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="89"/>
        <source>Class information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="140"/>
        <source>Bibliography</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="192"/>
        <source>Abstracts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="146"/>
        <source>Show available bibliography</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.ui" line="104"/>
        <source>Interacting drugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="123"/>
        <source>Synthetic interactions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="132"/>
        <source>Print all interactions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="139"/>
        <source>Print selected interaction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="166"/>
        <source>Send a report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="290"/>
        <source>Tested drugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/interactionsynthesisdialog.cpp" line="294"/>
        <source>Related to drugs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DailySchemeViewer</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dailyschemeviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dailyschemeviewer.ui" line="26"/>
        <source>Repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/dailyschemeviewer.ui" line="33"/>
        <source>Distribution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DatabaseSelectorWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.ui" line="26"/>
        <source>Available databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.ui" line="55"/>
        <source>Database information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DosageCreatorDialog</name>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.ui" line="90"/>
        <source>Show interaction synthesis dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.ui" line="118"/>
        <source>Available personal protocols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.ui" line="65"/>
        <source>DrugName</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="242"/>
        <source>Drug Dosage Creator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="260"/>
        <source>Current database website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="260"/>
        <source>Help and Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="261"/>
        <source>Prescribe only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="261"/>
        <source>Save protocol and prescribe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="261"/>
        <source>Save protocol only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageCreatorDialog.cpp" line="261"/>
        <source>Test interactions only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DosageDialog</name>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageDialog.ui" line="53"/>
        <source>PushButton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageDialog.ui" line="63"/>
        <source>Prescribe in INN mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageDialog.ui" line="66"/>
        <source>INN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageDialog.ui" line="90"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageDialog.cpp" line="91"/>
        <source>Drug Dosage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DosageViewer</name>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="17"/>
        <source>Show the summary of product characteristics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="28"/>
        <source>Protocol name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="103"/>
        <source>Basics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="128"/>
        <source>Intakes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="140"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="325"/>
        <source>Range x to y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="155"/>
        <source>Take</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="184"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="369"/>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="313"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="38"/>
        <source>External link to the product monograph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="41"/>
        <source>Product Monograph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="264"/>
        <source>Every</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="298"/>
        <source>Route(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="340"/>
        <source>For</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="431"/>
        <source>Used for INN prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="438"/>
        <source>100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="448"/>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="493"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="513"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="498"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="518"/>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="503"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="523"/>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="508"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="528"/>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="533"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="538"/>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="543"/>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="548"/>
        <source>00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="553"/>
        <source>01</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="558"/>
        <source>02</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="563"/>
        <source>03</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="568"/>
        <source>04</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="573"/>
        <source>05</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="578"/>
        <source>06</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="583"/>
        <source>07</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="588"/>
        <source>08</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="593"/>
        <source>09</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="598"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="603"/>
        <source>11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="608"/>
        <source>12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="613"/>
        <source>13</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="618"/>
        <source>14</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="623"/>
        <source>15</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="628"/>
        <source>16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="633"/>
        <source>17</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="638"/>
        <source>18</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="643"/>
        <source>19</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="648"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="653"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="658"/>
        <source>22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="663"/>
        <source>23</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="700"/>
        <source>Min interval between intakes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="738"/>
        <source>Meal time relation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="751"/>
        <source>Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="763"/>
        <source>Weight / Age / Sex Limited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="797"/>
        <source>Kg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="814"/>
        <source>No Sex limitation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="819"/>
        <source>Man only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="824"/>
        <source>Woman only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="839"/>
        <source>Min age</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="846"/>
        <source>Max age</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="853"/>
        <source>Min weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="860"/>
        <source>Sex limited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="879"/>
        <source>Renal function limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="913"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="942"/>
        <source>ml/min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="949"/>
        <source>Min clearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="956"/>
        <source>Max clearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="966"/>
        <source>Pregnancy / breast feeding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="972"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1004"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1026"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1064"/>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1086"/>
        <source>Work in progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="986"/>
        <source>Links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="992"/>
        <source>Links to CIM10 diagnosis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1014"/>
        <source>Links to eDRC diagnosis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1040"/>
        <source>Monitoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1052"/>
        <source>CIM10 Limitations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1074"/>
        <source>Biological monitoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1097"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1110"/>
        <source>Todos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1122"/>
        <source>Don&apos;t specify the form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1129"/>
        <source>INN prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.ui" line="1142"/>
        <source>Alternate with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.cpp" line="425"/>
        <source>Drug Dosage Creator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.cpp" line="607"/>
        <source>Clear this list</source>
        <comment>Clear the user&apos;s intakes recorded forms</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/dosagedialog/mfDosageViewer.cpp" line="646"/>
        <source>Linking to : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugEnginesPreferences</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugenginespreferences.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugEnginesPreferencesPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugenginespreferences.cpp" line="151"/>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugenginespreferences.cpp" line="153"/>
        <source>Interaction engines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugInfo</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="33"/>
        <source>drug name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="64"/>
        <source>Drug information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="78"/>
        <source>Known molecule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="101"/>
        <source>associated INN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="116"/>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="256"/>
        <source>Testers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="129"/>
        <source>Something is wrong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="142"/>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="296"/>
        <source>Explain what is wrong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="173"/>
        <source>Drug interaction class</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="122"/>
        <source>All information are exact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="155"/>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="309"/>
        <source>Send this information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="189"/>
        <source>Found drug interactions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="203"/>
        <source>Interactions from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="228"/>
        <source>Nature of the risk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="244"/>
        <source>What to do</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="262"/>
        <source>All interactions are found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="269"/>
        <source>All interactions are exact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="276"/>
        <source>All Interaction text is right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.ui" line="283"/>
        <source>All todos texts are right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugInfoPrivate</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="110"/>
        <source>INN Information will be lost.
Do you want to send them ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="175"/>
        <source>Testing : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="181"/>
        <source>All interactions found.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="183"/>
        <source>*** Missing interactions.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="187"/>
        <source>All interactions are OK.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="189"/>
        <source>*** Wrong interactions.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="193"/>
        <source>IAM Text is correct.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="195"/>
        <source>*** IAM Text is incorrect.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="199"/>
        <source>CAT Text is correct.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="201"/>
        <source>*** CAT Text is incorrect.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="204"/>
        <source>Message : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="210"/>
        <source>Checked interactions : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/druginfo.cpp" line="236"/>
        <source>ERROR : %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugSelector</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugselector.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugselector.cpp" line="195"/>
        <source>Selected drugs historic.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsActionHandler</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidgetmanager.cpp" line="643"/>
        <source>Prescription is not empty. Clear it ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidgetmanager.cpp" line="644"/>
        <source>You select another editing mode than the actual one. Changing of mode during edition may cause prescription lose.
Do you really want to change the editing mode ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsCentralWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/drugscentralwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsDatabaseSelectorPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.cpp" line="73"/>
        <source>Database selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/databaseselectorwidget.cpp" line="75"/>
        <source>Drug database selector</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsExtraOptionsPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="370"/>
        <source>Extras</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="372"/>
        <source>Drug&apos;s extra preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsExtraWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsextraoptionspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsextraoptionspage.ui" line="26"/>
        <source>Hide laboratory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsextraoptionspage.ui" line="45"/>
        <source>Text before 100% therapeutic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsextraoptionspage.ui" line="64"/>
        <source>Text after 100% therapeutic</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsPlugin</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugsplugin.cpp" line="157"/>
        <location filename="../../plugins/drugsplugin/drugsplugin.cpp" line="176"/>
        <source>Initializing drugs plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsPrintOptionsPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="214"/>
        <source>Printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="216"/>
        <source>Drug&apos;s printing preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="250"/>
        <source>Updating posologic sentence.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsPrintWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="33"/>
        <source>Old</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="45"/>
        <source>Drug font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="178"/>
        <source>Prescription font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="314"/>
        <source>Printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="336"/>
        <source>Add a line break between drugs when printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="351"/>
        <source>Prescription formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="358"/>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsprintoptionspage.ui" line="367"/>
        <source>Print duplicatas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="640"/>
        <source>This a note to take into account&lt;br /&gt;written in two lines...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsSelectorOptionsPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="145"/>
        <source>Selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="147"/>
        <source>Drug&apos;s selector preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsSelectorWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="14"/>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="43"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="20"/>
        <source>Available information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="29"/>
        <source>Drug commercial name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="36"/>
        <source>Route</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="50"/>
        <source>Strength</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="57"/>
        <source>Show composition in the tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="67"/>
        <source>Available personal protocols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="92"/>
        <source>Background color for drugs with available protocols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="102"/>
        <source>Allergies / Intolerances</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="134"/>
        <source>Drugs intolerances background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugselectorwidget.ui" line="108"/>
        <source>Drugs allergies background color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsUserOptionsPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="305"/>
        <source>User&apos;s documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="307"/>
        <source>User preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsUserWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsuseroptionspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsViewOptionsPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="72"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/mfDrugsPreferences.cpp" line="74"/>
        <source>Drug&apos;s view preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::DrugsViewWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="26"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="44"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="95"/>
        <source>Font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="102"/>
        <source>Size of historic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="122"/>
        <source>Patient&apos;s names order (needs restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="130"/>
        <source>Lastnames - Firstnames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="135"/>
        <source>Firstnames - Lastnames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="146"/>
        <source>Testers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="164"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="180"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="210"/>
        <source>Interactions warnings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="216"/>
        <source>Global level of passive notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="230"/>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="259"/>
        <source>Maximal information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="235"/>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="264"/>
        <source>Moderate information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="240"/>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="269"/>
        <source>Minimal information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="248"/>
        <source>Global level of dynamic notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="277"/>
        <source>Show interactions icons in the prescription window (static alerts)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/drugsviewoptionspage.ui" line="284"/>
        <source>Enable alerts needing acceptance (dynamic alerts)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::PrescriptionViewer</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/prescriptionviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::ProtocolPreferencesPage</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.cpp" line="61"/>
        <source>Drug&apos;s protocole preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::Internal::ProtocolPreferencesWidget</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="20"/>
        <source>Default intake schema</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="26"/>
        <source>When creating a new protocol, use the following default intake schema</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="33"/>
        <source>drugs form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="40"/>
        <source>the word: Intake(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="47"/>
        <source>other word:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="64"/>
        <source>Validation buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="70"/>
        <source>Default validation button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.ui" line="80"/>
        <source>When protocol has changed, toggle the validation button to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.cpp" line="137"/>
        <source>Save protocol and prescribe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.cpp" line="138"/>
        <source>Prescribe only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.cpp" line="139"/>
        <source>Save protocol only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugspreferences/protocolpreferencespage.cpp" line="140"/>
        <source>Test interactions only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrugsWidget::TextualPrescriptionDialog</name>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.ui" line="14"/>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.ui" line="26"/>
        <source>Textual prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.ui" line="49"/>
        <source>Drug name or drug label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.ui" line="65"/>
        <source>Prescription text or note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.ui" line="91"/>
        <source>100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.cpp" line="52"/>
        <source>Text can not contain any &apos;[&apos; or &apos;]&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/drugswidget/textualprescriptiondialog.cpp" line="52"/>
        <source>Please remove these chars from your texts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mfDrugsConstants</name>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="74"/>
        <source>Prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="75"/>
        <source>Toggle drug selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="76"/>
        <source>Search by commercial name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="77"/>
        <source>Search by INN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="78"/>
        <source>Search by molecules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="79"/>
        <source>Edition modes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="80"/>
        <source>Full prescriber</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="81"/>
        <source>Select only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="82"/>
        <source>Print prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="83"/>
        <source>Toggle testing drugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="84"/>
        <source>Open protocol dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="85"/>
        <source>Open posologic sentence preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="86"/>
        <source>Reset the prescription sentence to the default one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="87"/>
        <source>Show drug precautions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/drugsplugin/constants.h" line="88"/>
        <source>Drug precautions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
